<?php
   /*
    *  Printer Friendly
    *  Initial release by Luke Ehresman <luke@squirrelmail.org>
    *  Subsequent releases by Ray Black III <allah@accessnode.net>
    *  (c) 2001 (GNU GPL - see ../../COPYING)
    *
    *  This plugin creates a printer-friendly view of emails. The contents of
    *  the email come up in a new window, along with 'Print' and 'Close' buttons.
    *
    *  If you need help with this, or see improvements that can be made, please
    *  email me directly at the address above.  I definately welcome suggestions
    *  and comments.  This plugin, as is the case with all SquirrelMail plugins,
    *  is not directly supported by the developers.  Please come to me off the
    *  mailing list if you have trouble with it.
    *
    */

function squirrelmail_plugin_init_printer_friendly()
{
    global $squirrelmail_plugin_hooks, $pf_version, $version;
    
    $pf_version = substr($version, 0, 5);

    $squirrelmail_plugin_hooks['read_body_header_right']['printer_friendly']
        = 'printer_friendly';
    $squirrelmail_plugin_hooks['read_body_header']['printer_friendly']
        = 'printer_friendly_old';

    $squirrelmail_plugin_hooks['loading_prefs']['printer_friendly']
        = 'printer_friendly_loading_prefs';
    $squirrelmail_plugin_hooks['options_display_inside']['printer_friendly'] 
        = 'printer_friendly_options_display_inside';
    $squirrelmail_plugin_hooks['options_display_save']['printer_friendly'] 
        = 'printer_friendly_options_display_save';

} // end squirrelmail_plugin_init_printer_friendly()


function printer_friendly() {
    global $passed_id, $mailbox, $ent_num, $pf_version;
    global $pf_javascript, $pf_hookchoice;

    //this function should never be called by pre-1.1.2 clients, but what the hey...
    if ( $pf_version < '1.1.2' )
        return;

    if ( $pf_hookchoice == 'read_body_header' )
        return;

    if (strlen(trim($mailbox)) < 1)
        $mailbox = 'INBOX';

    if ( !empty($pf_javascript) && $pf_javascript == 'no' )
    {
?>

        <br><a target="_blank" href="../plugins/printer_friendly/bottom.php?passed_ent_id=<?php echo $ent_num ?>&mailbox=<?php echo urlencode($mailbox); ?>&passed_id=<?php echo $passed_id ?>">View printable version</a>

<?php

    }
    else // yay! javascript!
    {

?>
        <script language="javascript">
        <!--
        function printFormat() {
            window.open("../plugins/printer_friendly/main.php?passed_ent_id=<?php echo $ent_num ?>&mailbox=<?php echo urlencode($mailbox); ?>&passed_id=<?php echo $passed_id ?>","Print","width=800,height=600");
        }

        document.write('        <br><a href="javascript:printFormat();">View printable version</a>\n');
        // -->
        </script>
<?php

    } // end javascript check

} // end printer_friendly()


function printer_friendly_old() {
    global $passed_id, $mailbox, $ent_num, $color, $pf_version;
    global $pf_javascript, $pf_hookchoice;

    // this function could be called by pre-1.0.5 clients, and that'd be bad
    if ( $pf_version < '1.0.5' )
        return;

    // this is confusing, but it basically makes this the default mode for pre-1.1.2,
    // while making it the secondary choice for 1.1.2 and above.
    if ( (empty($pf_hookchoice) && $pf_version >= '1.1.2' )
            || $pf_hookchoice == 'read_body_header_right' )
        return;

    if (strlen(trim($mailbox)) < 1)
        $mailbox = 'INBOX';

    if ( !empty($pf_javascript) && $pf_javascript == 'no' )
    {
?>

      <tr bgcolor="<?php echo $color[0] ?>">
        <td class="medText" align="right" valign="top">
          &nbsp;
        </td><td class="medText" valign="top" colspan="2">
          <a target="_blank" href="../plugins/printer_friendly/bottom.php?passed_ent_id=<?php echo $ent_num ?>&mailbox=<?php echo urlencode($mailbox); ?>&passed_id=<?php echo $passed_id ?>">View printable version</a>
        </td>
      </tr>

<?php

    }
    else // yay! javascript!
    {

?>

        <script language="javascript">
        <!--
        function printFormat() {
            window.open("../plugins/printer_friendly/main.php?passed_ent_id=<?php echo $ent_num ?>&mailbox=<?php echo urlencode($mailbox); ?>&passed_id=<?php echo $passed_id ?>","Print","width=800,height=600");
        }

         // we output this from javascript so that it only shows to js-enabled browsers
        document.write('      <tr bgcolor="<?php echo $color[0] ?>">\n');
        document.write('        <td class="medText" align="right" valign="top"> &nbsp;\n');
        document.write('        </td><td class="medText" valign="top" colspan="2">\n');
        document.write('          <a href="javascript:printFormat();">View printable version</a><br>\n');
        document.write('        </td></tr>\n');
        // -->
        </script>

<?php

    } // end javascript check

} // end printer_friendly_old()


function printer_friendly_options_display_inside()
{
    global $username, $data_dir, $color, $pf_version;
    global $pf_javascript, $pf_hookchoice, $pf_cleandisplay;

    // this function could be called by pre-1.0.5 clients, and that'd be bad
    if ( $pf_version < '1.0.5' )
        return;

?>
    <tr>
        <td align="right">
            View Printable Email:
        </td>
        <td align="left">
            <table width="100%" cellpadding="1" cellspacing="0" border="0">
            <tr><td bgcolor="<?php echo $color[0]; ?>" align="center">
                <table width="100%" cellpadding="2" cellspacing="0" border="0">
                <tr><td bgcolor="<?php echo $color[4]; ?>" align="left" valign="middle">
                    <small>
                    <input type="checkbox" name="pf_javascript_tmp" value="yes"<?php if ($pf_javascript != 'no') echo ' checked' ?>>
                    Use Javascript

                    &nbsp;|&nbsp;
                    <input type="checkbox" name="pf_cleandisplay_tmp" value="yes"<?php if ($pf_cleandisplay != 'no') echo ' checked' ?>>
                    Clean Display

<?php
    // this pref shouldn't be set in pre-1.1.2 clients
    if ( $pf_version >= '1.1.2' ):
?>

                    <br>
                    <input type="checkbox" name="pf_hookchoice_tmp" value="yes"<?php if ($pf_hookchoice != 'read_body_header') echo ' checked' ?>>
                    Subtle Link

<?php
    endif;
?>

        			</small>
                </td></tr>
                </table>
            </td></tr>
            </table>
        </td>
    </tr>
<?
} // end printer_friendly_options_display_inside()

function printer_friendly_options_display_save()
{
    global $username, $data_dir, $pf_version;
    global $pf_javascript_tmp, $pf_hookchoice_tmp, $pf_cleandisplay_tmp;

  // this function could be called by pre-1.0.5 clients, and that'd be bad
  if ( $pf_version < '1.0.5' )
      return;

    if (isset($pf_javascript_tmp) && $pf_javascript_tmp == 'yes') {
        setPref($data_dir, $username, 'pf_javascript', 'yes');
    } else {
        setPref($data_dir, $username, 'pf_javascript', 'no');
    }

    if (isset($pf_cleandisplay_tmp) && $pf_cleandisplay_tmp == 'yes') {
        setPref($data_dir, $username, 'pf_cleandisplay', 'yes');
    } else {
        setPref($data_dir, $username, 'pf_cleandisplay', 'no');
    }


  // this preference shouldn't be set in pre-1.1.2 clients
  if ( $pf_version < '1.1.2' )
      return;

    if (isset($pf_hookchoice_tmp) && $pf_hookchoice_tmp == 'yes') {
        setPref($data_dir, $username, 'pf_hookchoice', 'read_body_header_right');
    } else {
        setPref($data_dir, $username, 'pf_hookchoice', 'read_body_header');
    }

} // end printer_friendly_options_display_save()


function printer_friendly_loading_prefs() {

	global $username, $data_dir, $pf_version;
    global $pf_javascript, $pf_hookchoice, $pf_cleandisplay;

  // neither of these preferences should be set in pre-1.0.5 clients
  if ( $pf_version < '1.0.5' )
      return;

	$pf_javascript   = getPref($data_dir, $username, 'pf_javascript');
	$pf_cleandisplay = getPref($data_dir, $username, 'pf_cleandisplay');

  // this preference shouldn't be set in pre-1.1.2 clients
  if ( $pf_version < '1.1.2' )
      return;

	$pf_hookchoice = getPref($data_dir, $username, 'pf_hookchoice');

} // end printer_friendly_loading_prefs()


?>